Index — cocos v0.6.10 documentation

# Index – H

h (Matrix4 attribute) handle() (Resource method) handle_closing() (Director method) height() (Rect property) (Sprite property) hex_width() (in module cocos.tiles) HexCell (class in cocos.tiles) HexMap (class in cocos.tiles) | hexmap_factory() (in module cocos.tiles) HexMapLayer (class in cocos.tiles) Hide (class in cocos.actions.instant_actions) hide_all() (TransitionScene method) hide_out_show_in() (TransitionScene method) HTMLLabel (class in cocos.text)